# ------------------------------------------------------------------------------
#
# **AMS Smooth Zoom**
#
# Makes zoom in/out mouse wheel transitions smoother, just like in new apps.
#
# Homepage
#   http://sketchucation.com/forums/viewtopic.php?f=323&t=59140
#
# Usage
#   * Rotate mouse wheel to zoom in/out as you would in original way.
#   * Use the plugin menu to enable/disable smooth zoom and to adjust settings.
#
# Access
#   (Menu) Plugins/Extensions → Smooth Zoom → [Option]
#
# Requirements
#   - Microsoft Windows XP, Vista, 7, 8, 10
#   - SketchUp 6 or later
#   - AMS Library 3.1.2 or later
#
# Version
#   1.2.0
#
# Release Date
#   December 4, 2015
#
# Author
#   Anton Synytsia (anton.synytsia@gmail.com).
#
# ------------------------------------------------------------------------------

require 'sketchup.rb'
require 'extensions.rb'

load_me = true

# Verify operation system.
if RUBY_PLATFORM !~ /mswin|mingw/i
  load_me = false
  msg = "'AMS Smooth Zoom' extension can operate on MSFT Windows based platforms only! "
  msg << "Your operating system doesn't smell like Windows to me."
  UI.messagebox(msg)
  #~ dir = File.dirname(__FILE__)
  #~ File.rename(__FILE__, File.join(dir, 'ams_SmoothZoom.rb!'))
end

# Load and verify AMS Library.
begin
  require 'ams_Lib/main.rb'
  raise 'Outdated library!' if AMS::Lib::VERSION.delete('.').to_i < 312
rescue StandardError, LoadError
  msg = "'AMS Smooth Zoom' extension requires AMS Library version 3.1.2 or later! "
  msg << "This extension will not work without the library installed. "
  msg << "Would you like to get to the library's download page?"
  load_me = false
  if UI.messagebox(msg, MB_YESNO) == IDYES
    UI.openURL('http://sketchucation.com/forums/viewtopic.php?f=323&t=55067#p499835')
  end
end if load_me

module AMS::SmoothZoom

  NAME         = 'AMS Smooth Zoom'.freeze
  VERSION      = '1.2.0'.freeze
  RELEASE_DATE = 'December 4, 2015'.freeze

  # Create the extension.
  @extension = SketchupExtension.new(NAME, 'ams_SmoothZoom/main.rb')

  desc = 'Makes mouse wheel zoom in/out transitions smoother.'

  # Attach some nice info.
  @extension.description = desc
  @extension.version     = VERSION
  @extension.copyright   = 'Copyright © 2015, Anton Synytsia'
  @extension.creator     = 'Anton Synytsia (anton.synytsia@gmail.com)'

  # Register and load the extension on start-up.
  Sketchup.register_extension(@extension, true)

  class << self
    attr_reader :extension
  end

end if load_me
